@@ -248,7 +248,8 @@ class PgStorage(SqlStorage):
                     '(name TEXT, value TEXT);')
             self._execute(stmt, cursor)
             stmt = ('CREATE UNLOGGED TABLE IF NOT EXISTS "__symtable" '
-                    '(name TEXT, type TEXT, appdata TEXT);')
+                    '(name TEXT, type TEXT, appdata TEXT,'
+                    ' UNIQUE(name));')
             self._execute(stmt, cursor)
             stmt = ('CREATE UNLOGGED TABLE IF NOT EXISTS "__queries" '
                     '(sco_id TEXT, query_id TEXT);')
@@ -268,8 +269,28 @@ class PgStorage(SqlStorage):
     def _migrate(self, version, cursor):
         if version == '2':
             self._execute(COLUMNS_TABLE, cursor)
-            return True
-        return False
+            version = '2.1'
+        if version == '2.1':
+            # Add unique contraint to __symtable
+            # First de-dup the table
+            data = self.get_view_data()
+            views = {}
+            for row in data:
+                views[row['name']] = row
+            cursor = self._execute('BEGIN;')
+            self._execute('DROP TABLE __symtable', cursor)
+            stmt = ('CREATE UNLOGGED TABLE IF NOT EXISTS "__symtable" '
+                    '(name TEXT, type TEXT, appdata TEXT,'
+                    ' UNIQUE(name));')
+            self._execute(stmt, cursor)
+            for view in views.values():
+                stmt = (f'INSERT INTO "__symtable" (name, type, appdata)'
+                        f' VALUES ({self.placeholder}, {self.placeholder}, {self.placeholder})')
+                cursor.execute(stmt, (view['name'], view['type'], view['appdata']))
+            self.connection.commit()
+            cursor.close()
+            version = '2.2'
+        return version == DB_VERSION
 
     def _get_writer(self, **kwargs):
         """Get a DB inserter object"""
